@@ -30,19 +30,18 @@
 
 CONFIG_DIRS=""
 
-isDebian=$(grep -c "Debian" /etc/issue)
-isRhel=$(grep -c "Red Hat" /etc/issue)
-
-if [ ${isDebian} -eq 1 ] ; then
+if [ -f /etc/debian_version ] ; then
    # determibe Debian OS version, 5 - lenny, 6 - squeeze, 7 - wheezy
    dist=debian
-   os_version=$(grep Linux /etc/issue | sed -e "s/.*Linux //" -e "s/\.[0-9]*//" -e "s/ .*//")
+   os_version=$(cat /etc/debian_version | sed -e "s/\.[0-9]*//" -e "s/\.[0-9]*//" )
 fi
-if [ ${isRhel} -eq 1 ] ; then
+
+if [ -f /etc/redhat-release ] ; then
    # determibe Red Hat OS version
    dist=rhel
-   os_version=$(grep Linux /etc/issue | sed -e "s/\.[0-9]* \(.*\)//" -e "s/.* //")
+   os_version=$(cat /etc/redhat-release | sed -e "s/\.[0-9]* \(.*\)//" -e "s/.* //")
 fi
+
 dist_version=${dist}${os_version}
 
 # setup the name of the share directory where external software
